query GithubRepositories {
    githubRepositories {
        __typename
        ... on Repositories {
            repositories {
                id
                githubOrgName
                githubRepoName
                createdAt
                updatedAt
            }
        }
        ... on Error {
            message
        }
    }
}
