mutation StartChatTurn($chatInput: ChatInput!, $parentUuid: String, $chatConfig: ChatConfig!) {
    startChatReply(
        chatInput: $chatInput,
        parentUuid: $parentUuid,
        chatConfig: $chatConfig
    ) {
        __typename
        ... on UnauthenticatedError {
            message
        }
        ... on ChatNotFoundError {
            message
        }
        ... on Chat {
            chatUuid
        }
    }
}
