mutation RebuildCloudRepository($orgName: String!, $repoName: String!) {
    rebuildCloudRepository(orgName: $orgName, repoName: $repoName) {
        __typename
        ... on ContainerImages {
            images {
                buildRef
                createdAt
                updatedAt
            }
        }
        ... on UnauthenticatedError {
            message
        }
        ... on CloudConfigNotFoundError {
            message
        }
        ... on GithubConfigNotFoundError {
            message
        }
        ... on CloudSessionError {
            message
        }
        ... on Error {
            message
        }
    }
}
