# Generated by ariadne-codegen
# Source: ../../schema.graphql

from enum import Enum


class ExponentModels(str, Enum):
    BASE = "BASE"
    PREMIUM = "PREMIUM"


class ModelName(str, Enum):
    GPT_3_POINT_5_TURBO = "GPT_3_POINT_5_TURBO"
    GPT_4_TURBO = "GPT_4_TURBO"
    GPT_4O = "GPT_4O"
    GPT_40_05_13 = "GPT_40_05_13"
    GPT_4O_LATEST = "GPT_4O_LATEST"
    GPT_4O_MINI = "GPT_4O_MINI"
    GPT_4_1 = "GPT_4_1"
    GPT_4_1_MINI = "GPT_4_1_MINI"
    GPT_4_1_NANO = "GPT_4_1_NANO"
    GPT_O1 = "GPT_O1"
    GPT_O1_MINI = "GPT_O1_MINI"
    GPT_O3 = "GPT_O3"
    GPT_O3_MINI = "GPT_O3_MINI"
    GPT_O3_MINI_HIGH = "GPT_O3_MINI_HIGH"
    GPT_5 = "GPT_5"
    GPT_5_CODEX = "GPT_5_CODEX"
    GPT_5_MINI = "GPT_5_MINI"
    GPT_5_NANO = "GPT_5_NANO"
    GPT_4O_FT_0 = "GPT_4O_FT_0"
    CLAUDE_4_OPUS = "CLAUDE_4_OPUS"
    CLAUDE_4_SONNET = "CLAUDE_4_SONNET"
    CLAUDE_SONNET_4_5_20250929 = "CLAUDE_SONNET_4_5_20250929"
    CLAUDE_OPUS_4_5_20251101 = "CLAUDE_OPUS_4_5_20251101"
    CLAUDE_3_OPUS = "CLAUDE_3_OPUS"
    CLAUDE_3_POINT_5_SONNET_1022 = "CLAUDE_3_POINT_5_SONNET_1022"
    CLAUDE_3_7_SONNET_20250219 = "CLAUDE_3_7_SONNET_20250219"
    CLAUDE_3_5_HAIKU = "CLAUDE_3_5_HAIKU"
    CLAUDE_4_5_HAIKU = "CLAUDE_4_5_HAIKU"
    TOGETHERAI_LLAMA_3_POINT_1_405B = "TOGETHERAI_LLAMA_3_POINT_1_405B"
    FIREWORKS_AI_LLAMA_3_POINT_1_405B = "FIREWORKS_AI_LLAMA_3_POINT_1_405B"
    FIREWORKS_AI_DEEPSEEK_V3 = "FIREWORKS_AI_DEEPSEEK_V3"
    TOGETHERAI_LLAMA_3_POINT_1_70B = "TOGETHERAI_LLAMA_3_POINT_1_70B"
    GROK_2 = "GROK_2"
    GROK_3_BETA = "GROK_3_BETA"
    GROK_3_MINI_REASONING_BETA = "GROK_3_MINI_REASONING_BETA"
    GROK_CODE_FAST_1 = "GROK_CODE_FAST_1"
    GEMINI_1_5_FLASH = "GEMINI_1_5_FLASH"
    GEMINI_1_5_FLASH_8B = "GEMINI_1_5_FLASH_8B"
    GEMINI_EXP_1206 = "GEMINI_EXP_1206"
    GEMINI_20_FLASH_EXP = "GEMINI_20_FLASH_EXP"
    GEMINI_2_5_PRO = "GEMINI_2_5_PRO"
    GEMINI_3_PRO = "GEMINI_3_PRO"
    DEEPSEEK_2_POINT_5 = "DEEPSEEK_2_POINT_5"
    DEEPSEEK_V3 = "DEEPSEEK_V3"
    DEEPSEEK_R1 = "DEEPSEEK_R1"
    RELACE_INSTANT_APPLY = "RELACE_INSTANT_APPLY"


class ReasoningLevel(str, Enum):
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"


class SandboxProvider(str, Enum):
    DAYTONA = "DAYTONA"
    E2B = "E2B"
    MODAL = "MODAL"


class ToolPermissionStatus(str, Enum):
    REQUESTED = "REQUESTED"
    CONFIRMED = "CONFIRMED"
    AUTOCONFIRMED = "AUTOCONFIRMED"
    REJECTED = "REJECTED"


class UseToolsMode(str, Enum):
    read_only = "read_only"
    read_write = "read_write"
    disabled = "disabled"
