mutation ReportSandboxInfo(
  $sandboxId: String!,
  $diskUsageGb: Float,
  $indentLogFile: String
) {
  reportSandboxInfo(
    sandboxId: $sandboxId,
    diskUsageGb: $diskUsageGb,
    indentLogFile: $indentLogFile
  ) {
    __typename
    ... on SandboxInfoResponse {
      success
      message
    }
    ... on UnauthenticatedError {
      message
    }
    ... on Error {
      message
    }
  }
}
