# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Literal, Union

from pydantic import Field

from .base_model import BaseModel


class SetLoginComplete(BaseModel):
    set_login_complete: Union[
        "SetLoginCompleteSetLoginCompleteUser",
        "SetLoginCompleteSetLoginCompleteUnauthenticatedError",
    ] = Field(alias="setLoginComplete", discriminator="typename__")


class SetLoginCompleteSetLoginCompleteUser(BaseModel):
    typename__: Literal["User"] = Field(alias="__typename")
    user_api_key: str = Field(alias="userApiKey")


class SetLoginCompleteSetLoginCompleteUnauthenticatedError(BaseModel):
    typename__: Literal["UnauthenticatedError"] = Field(alias="__typename")
    message: str


SetLoginComplete.model_rebuild()
