mutation HaltChatStream($chatUuid: UUID!) {
    haltChatStream(chatUuid: $chatUuid) {
        __typename
        ... on Chat {
            chatUuid
        }
        ... on UnauthenticatedError {
            message
        }
        ... on ChatNotFoundError {
            message
        }
        ... on RemoteExecutionError {
            message
        }
    }
}
