mutation SetLoginComplete {
    setLoginComplete {
        __typename
        ... on User {
            userApiKey
        }
        ... on UnauthenticatedError {
            message
        }
    }
}
