# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Literal, Union

from pydantic import Field

from .base_model import BaseModel


class ReportSandboxInfo(BaseModel):
    report_sandbox_info: Union[
        "ReportSandboxInfoReportSandboxInfoSandboxInfoResponse",
        "ReportSandboxInfoReportSandboxInfoUnauthenticatedError",
        "ReportSandboxInfoReportSandboxInfoError",
    ] = Field(alias="reportSandboxInfo", discriminator="typename__")


class ReportSandboxInfoReportSandboxInfoSandboxInfoResponse(BaseModel):
    typename__: Literal["SandboxInfoResponse"] = Field(alias="__typename")
    success: bool
    message: str


class ReportSandboxInfoReportSandboxInfoUnauthenticatedError(BaseModel):
    typename__: Literal["UnauthenticatedError"] = Field(alias="__typename")
    message: str


class ReportSandboxInfoReportSandboxInfoError(BaseModel):
    typename__: Literal["Error"] = Field(alias="__typename")
    message: str


ReportSandboxInfo.model_rebuild()
