# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Any, List, Literal, Union

from pydantic import Field

from .base_model import BaseModel


class GithubRepositories(BaseModel):
    github_repositories: Union[
        "GithubRepositoriesGithubRepositoriesRepositories",
        "GithubRepositoriesGithubRepositoriesError",
    ] = Field(alias="githubRepositories", discriminator="typename__")


class GithubRepositoriesGithubRepositoriesRepositories(BaseModel):
    typename__: Literal["Repositories"] = Field(alias="__typename")
    repositories: List["GithubRepositoriesGithubRepositoriesRepositoriesRepositories"]


class GithubRepositoriesGithubRepositoriesRepositoriesRepositories(BaseModel):
    id: str
    github_org_name: str = Field(alias="githubOrgName")
    github_repo_name: str = Field(alias="githubRepoName")
    created_at: Any = Field(alias="createdAt")
    updated_at: Any = Field(alias="updatedAt")


class GithubRepositoriesGithubRepositoriesError(BaseModel):
    typename__: Literal["Error"] = Field(alias="__typename")
    message: str


GithubRepositories.model_rebuild()
GithubRepositoriesGithubRepositoriesRepositories.model_rebuild()
