query Chats {
    chats {
        ... on UnauthenticatedError {
            message
        }
        ... on Chats {
            chats {
                id
                chatUuid
                name
                subtitle
                isShared
                isStarted
                updatedAt
            }
        }
    }
}
