# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Literal, Union

from pydantic import Field

from .base_model import BaseModel


class RefreshApiKey(BaseModel):
    refresh_api_key: Union[
        "RefreshApiKeyRefreshApiKeyUser",
        "RefreshApiKeyRefreshApiKeyUnauthenticatedError",
    ] = Field(alias="refreshApiKey", discriminator="typename__")


class RefreshApiKeyRefreshApiKeyUser(BaseModel):
    typename__: Literal["User"] = Field(alias="__typename")
    user_api_key: str = Field(alias="userApiKey")


class RefreshApiKeyRefreshApiKeyUnauthenticatedError(BaseModel):
    typename__: Literal["UnauthenticatedError"] = Field(alias="__typename")
    message: str


RefreshApiKey.model_rebuild()
